@@ -1,10 +1,9 @@
-__version__ = "0.0.11"
+__version__ = "0.0.12"
 
 from . import flim
 from . import image_processing
 from . import io
 from . import metrics
-from . import summarizing
 from . import visualization
 
 
@@ -13,6 +12,5 @@ __all__ = [
     'image_processing',
     'io',
     'metrics',
-    'summarizing',
     'visualization',
     ]
\ No newline at end of file
